Beamline Scientists Documents
=============================

If you are a beamline scientist or a user who is conducting experiment at the beamline and you are using the
bluesky to collect the data, here is the tutorial to setup a server that can process the data in real time.

In the subsections, you will find several servers that you can run for the real time streaming data analysis.
Before you start a server, you always needs a proxy running, please look at ZMQ Proxy section to know how to
start a proxy.

.. toctree::
   :maxdepth: 1

   zmq_proxy
   xpd_server
